{% extends "admin/base_site.html" %}

<!-- LOADING -->
{% load admin_static i18n fb_tags fb_versions fb_compat %}

<!-- BREADCRBUMBS -->
{% block breadcrumbs %}{% include "filebrowser/include/breadcrumbs.html" %}{% endblock %}

<!-- CONTENT -->
{% block content %}
    <!-- POP-UP BREADCRUMBS -->
    {% if query.pop %}
        {% include "filebrowser/include/breadcrumbs.html" %}
    {% endif %}
    <p>{% blocktrans with fileobject.filename as escaped_object %}Are you sure you want to delete the {{ object_name }} "{{ escaped_object }}"? All of the following related items will be deleted:{% endblocktrans %}</p>

    <ul>
        <li>{{ fileobject.filename }}</li>
    </ul>

    {% if filelisting %}
        <ul>
            {% for item in filelisting %}
                <li>{{ item.path_relative_directory }}</li>
            {% endfor %}
        <ul>
    {% endif %}
    {% if additional_files %}
        <ul>
            <li>{% blocktrans with additional_files as escaped_object %}... and {{ escaped_object }} more Files.{% endblocktrans %}</li>
        </ul>
    {% endif %}

    <form action="{% url 'filebrowser:fb_delete' %}{% query_string %}" method="post">
    {% csrf_token %}
    <div>
    <input type="submit" value="{% trans "Yes, I'm sure" %}" />
    </div>
    </form>
{% endblock %}
